@@ -420,3 +420,131 @@ class ListPhraseMatchersAsyncPager:
 
     def __repr__(self) -> str:
         return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListViewsPager:
+    """A pager for iterating through ``list_views`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.contact_center_insights_v1.types.ListViewsResponse` object, and
+    provides an ``__iter__`` method to iterate through its
+    ``views`` field.
+
+    If there are more pages, the ``__iter__`` method will make additional
+    ``ListViews`` requests and continue to iterate
+    through the ``views`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.contact_center_insights_v1.types.ListViewsResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., contact_center_insights.ListViewsResponse],
+        request: contact_center_insights.ListViewsRequest,
+        response: contact_center_insights.ListViewsResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiate the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.contact_center_insights_v1.types.ListViewsRequest):
+                The initial request object.
+            response (google.cloud.contact_center_insights_v1.types.ListViewsResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = contact_center_insights.ListViewsRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    def pages(self) -> Iterator[contact_center_insights.ListViewsResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __iter__(self) -> Iterator[resources.View]:
+        for page in self.pages:
+            yield from page.views
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
+
+
+class ListViewsAsyncPager:
+    """A pager for iterating through ``list_views`` requests.
+
+    This class thinly wraps an initial
+    :class:`google.cloud.contact_center_insights_v1.types.ListViewsResponse` object, and
+    provides an ``__aiter__`` method to iterate through its
+    ``views`` field.
+
+    If there are more pages, the ``__aiter__`` method will make additional
+    ``ListViews`` requests and continue to iterate
+    through the ``views`` field on the
+    corresponding responses.
+
+    All the usual :class:`google.cloud.contact_center_insights_v1.types.ListViewsResponse`
+    attributes are available on the pager. If multiple requests are made, only
+    the most recent response is retained, and thus used for attribute lookup.
+    """
+
+    def __init__(
+        self,
+        method: Callable[..., Awaitable[contact_center_insights.ListViewsResponse]],
+        request: contact_center_insights.ListViewsRequest,
+        response: contact_center_insights.ListViewsResponse,
+        *,
+        metadata: Sequence[Tuple[str, str]] = ()
+    ):
+        """Instantiates the pager.
+
+        Args:
+            method (Callable): The method that was originally called, and
+                which instantiated this pager.
+            request (google.cloud.contact_center_insights_v1.types.ListViewsRequest):
+                The initial request object.
+            response (google.cloud.contact_center_insights_v1.types.ListViewsResponse):
+                The initial response object.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        """
+        self._method = method
+        self._request = contact_center_insights.ListViewsRequest(request)
+        self._response = response
+        self._metadata = metadata
+
+    def __getattr__(self, name: str) -> Any:
+        return getattr(self._response, name)
+
+    @property
+    async def pages(self) -> AsyncIterator[contact_center_insights.ListViewsResponse]:
+        yield self._response
+        while self._response.next_page_token:
+            self._request.page_token = self._response.next_page_token
+            self._response = await self._method(self._request, metadata=self._metadata)
+            yield self._response
+
+    def __aiter__(self) -> AsyncIterator[resources.View]:
+        async def async_generator():
+            async for page in self.pages:
+                for response in page.views:
+                    yield response
+
+        return async_generator()
+
+    def __repr__(self) -> str:
+        return "{0}<{1!r}>".format(self.__class__.__name__, self._response)
