@@ -18,11 +18,11 @@ from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
 import pkg_resources
 
 import google.auth  # type: ignore
-import google.api_core  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
-from google.api_core import operations_v1  # type: ignore
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.api_core import operations_v1
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
@@ -105,7 +105,6 @@ class ContactCenterInsightsTransport(abc.ABC):
             credentials, _ = google.auth.load_credentials_from_file(
                 credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
-
         elif credentials is None:
             credentials, _ = google.auth.default(
                 **scopes_kwargs, quota_project_id=quota_project_id
@@ -212,6 +211,11 @@ class ContactCenterInsightsTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.update_phrase_matcher: gapic_v1.method.wrap_method(
+                self.update_phrase_matcher,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.calculate_stats: gapic_v1.method.wrap_method(
                 self.calculate_stats, default_timeout=None, client_info=client_info,
             ),
@@ -221,6 +225,21 @@ class ContactCenterInsightsTransport(abc.ABC):
             self.update_settings: gapic_v1.method.wrap_method(
                 self.update_settings, default_timeout=None, client_info=client_info,
             ),
+            self.create_view: gapic_v1.method.wrap_method(
+                self.create_view, default_timeout=None, client_info=client_info,
+            ),
+            self.get_view: gapic_v1.method.wrap_method(
+                self.get_view, default_timeout=None, client_info=client_info,
+            ),
+            self.list_views: gapic_v1.method.wrap_method(
+                self.list_views, default_timeout=None, client_info=client_info,
+            ),
+            self.update_view: gapic_v1.method.wrap_method(
+                self.update_view, default_timeout=None, client_info=client_info,
+            ),
+            self.delete_view: gapic_v1.method.wrap_method(
+                self.delete_view, default_timeout=None, client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -480,6 +499,15 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def update_phrase_matcher(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UpdatePhraseMatcherRequest],
+        Union[resources.PhraseMatcher, Awaitable[resources.PhraseMatcher]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def calculate_stats(
         self,
@@ -510,5 +538,53 @@ class ContactCenterInsightsTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def create_view(
+        self,
+    ) -> Callable[
+        [contact_center_insights.CreateViewRequest],
+        Union[resources.View, Awaitable[resources.View]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def get_view(
+        self,
+    ) -> Callable[
+        [contact_center_insights.GetViewRequest],
+        Union[resources.View, Awaitable[resources.View]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def list_views(
+        self,
+    ) -> Callable[
+        [contact_center_insights.ListViewsRequest],
+        Union[
+            contact_center_insights.ListViewsResponse,
+            Awaitable[contact_center_insights.ListViewsResponse],
+        ],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def update_view(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UpdateViewRequest],
+        Union[resources.View, Awaitable[resources.View]],
+    ]:
+        raise NotImplementedError()
+
+    @property
+    def delete_view(
+        self,
+    ) -> Callable[
+        [contact_center_insights.DeleteViewRequest],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
+    ]:
+        raise NotImplementedError()
+
 
 __all__ = ("ContactCenterInsightsTransport",)
