@@ -16,9 +16,9 @@
 import warnings
 from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
-from google.api_core import grpc_helpers  # type: ignore
-from google.api_core import operations_v1  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
+from google.api_core import grpc_helpers
+from google.api_core import operations_v1
+from google.api_core import gapic_v1
 import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
@@ -945,6 +945,34 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
             )
         return self._stubs["delete_phrase_matcher"]
 
+    @property
+    def update_phrase_matcher(
+        self,
+    ) -> Callable[
+        [contact_center_insights.UpdatePhraseMatcherRequest], resources.PhraseMatcher
+    ]:
+        r"""Return a callable for the update phrase matcher method over gRPC.
+
+        Updates a phrase matcher.
+
+        Returns:
+            Callable[[~.UpdatePhraseMatcherRequest],
+                    ~.PhraseMatcher]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "update_phrase_matcher" not in self._stubs:
+            self._stubs["update_phrase_matcher"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/UpdatePhraseMatcher",
+                request_serializer=contact_center_insights.UpdatePhraseMatcherRequest.serialize,
+                response_deserializer=resources.PhraseMatcher.deserialize,
+            )
+        return self._stubs["update_phrase_matcher"]
+
     @property
     def calculate_stats(
         self,
@@ -1026,6 +1054,139 @@ class ContactCenterInsightsGrpcTransport(ContactCenterInsightsTransport):
             )
         return self._stubs["update_settings"]
 
+    @property
+    def create_view(
+        self,
+    ) -> Callable[[contact_center_insights.CreateViewRequest], resources.View]:
+        r"""Return a callable for the create view method over gRPC.
+
+        Creates a view.
+
+        Returns:
+            Callable[[~.CreateViewRequest],
+                    ~.View]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "create_view" not in self._stubs:
+            self._stubs["create_view"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/CreateView",
+                request_serializer=contact_center_insights.CreateViewRequest.serialize,
+                response_deserializer=resources.View.deserialize,
+            )
+        return self._stubs["create_view"]
+
+    @property
+    def get_view(
+        self,
+    ) -> Callable[[contact_center_insights.GetViewRequest], resources.View]:
+        r"""Return a callable for the get view method over gRPC.
+
+        Gets a view.
+
+        Returns:
+            Callable[[~.GetViewRequest],
+                    ~.View]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_view" not in self._stubs:
+            self._stubs["get_view"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/GetView",
+                request_serializer=contact_center_insights.GetViewRequest.serialize,
+                response_deserializer=resources.View.deserialize,
+            )
+        return self._stubs["get_view"]
+
+    @property
+    def list_views(
+        self,
+    ) -> Callable[
+        [contact_center_insights.ListViewsRequest],
+        contact_center_insights.ListViewsResponse,
+    ]:
+        r"""Return a callable for the list views method over gRPC.
+
+        Lists views.
+
+        Returns:
+            Callable[[~.ListViewsRequest],
+                    ~.ListViewsResponse]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_views" not in self._stubs:
+            self._stubs["list_views"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/ListViews",
+                request_serializer=contact_center_insights.ListViewsRequest.serialize,
+                response_deserializer=contact_center_insights.ListViewsResponse.deserialize,
+            )
+        return self._stubs["list_views"]
+
+    @property
+    def update_view(
+        self,
+    ) -> Callable[[contact_center_insights.UpdateViewRequest], resources.View]:
+        r"""Return a callable for the update view method over gRPC.
+
+        Updates a view.
+
+        Returns:
+            Callable[[~.UpdateViewRequest],
+                    ~.View]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "update_view" not in self._stubs:
+            self._stubs["update_view"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/UpdateView",
+                request_serializer=contact_center_insights.UpdateViewRequest.serialize,
+                response_deserializer=resources.View.deserialize,
+            )
+        return self._stubs["update_view"]
+
+    @property
+    def delete_view(
+        self,
+    ) -> Callable[[contact_center_insights.DeleteViewRequest], empty_pb2.Empty]:
+        r"""Return a callable for the delete view method over gRPC.
+
+        Deletes a view.
+
+        Returns:
+            Callable[[~.DeleteViewRequest],
+                    ~.Empty]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_view" not in self._stubs:
+            self._stubs["delete_view"] = self.grpc_channel.unary_unary(
+                "/google.cloud.contactcenterinsights.v1.ContactCenterInsights/DeleteView",
+                request_serializer=contact_center_insights.DeleteViewRequest.serialize,
+                response_deserializer=empty_pb2.Empty.FromString,
+            )
+        return self._stubs["delete_view"]
+
     def close(self):
         self.grpc_channel.close()
 
