@@ -68,8 +68,15 @@ __protobuf__ = proto.module(
         "ListPhraseMatchersResponse",
         "GetPhraseMatcherRequest",
         "DeletePhraseMatcherRequest",
+        "UpdatePhraseMatcherRequest",
         "GetSettingsRequest",
         "UpdateSettingsRequest",
+        "CreateViewRequest",
+        "GetViewRequest",
+        "ListViewsRequest",
+        "ListViewsResponse",
+        "UpdateViewRequest",
+        "DeleteViewRequest",
     },
 )
 
@@ -122,8 +129,13 @@ class CalculateStatsResponse(proto.Message):
             A map associating each issue resource name with its
             respective number of matches in the set of conversations.
             Key has the format:
-            ``projects/<Project ID>/locations/<Location ID>/issueModels/<Issue Model ID>/issues/<Issue ID>``
+            ``projects/<Project-ID>/locations/<Location-ID>/issueModels/<Issue-Model-ID>/issues/<Issue-ID>``
             Deprecated, use ``issue_matches_stats`` field instead.
+        issue_matches_stats (Sequence[google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.IssueMatchesStatsEntry]):
+            A map associating each issue resource name with its
+            respective number of matches in the set of conversations.
+            Key has the format:
+            ``projects/<Project-ID>/locations/<Location-ID>/issueModels/<Issue-Model-ID>/issues/<Issue-ID>``
         conversation_count_time_series (google.cloud.contact_center_insights_v1.types.CalculateStatsResponse.TimeSeries):
             A time series representing the count of
             conversations created over time that match that
@@ -176,6 +188,12 @@ class CalculateStatsResponse(proto.Message):
     smart_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=4,)
     custom_highlighter_matches = proto.MapField(proto.STRING, proto.INT32, number=5,)
     issue_matches = proto.MapField(proto.STRING, proto.INT32, number=6,)
+    issue_matches_stats = proto.MapField(
+        proto.STRING,
+        proto.MESSAGE,
+        number=8,
+        message=resources.IssueModelLabelStats.IssueStats,
+    )
     conversation_count_time_series = proto.Field(
         proto.MESSAGE, number=7, message=TimeSeries,
     )
@@ -216,9 +234,9 @@ class CreateConversationRequest(proto.Message):
             the final component of the conversation's resource name. If
             no ID is specified, a server-generated ID will be used.
 
-            This value should be 4-32 characters and must match the
-            regular expression /^[a-z0-9-]{4,32}$/. Valid characters are
-            /[a-z][0-9]-/
+            This value should be 4-64 characters and must match the
+            regular expression ``^[a-z0-9-]{4,64}$``. Valid characters
+            are ``[a-z][0-9]-``
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -430,6 +448,7 @@ class ExportInsightsDataRequest(proto.Message):
     Attributes:
         big_query_destination (google.cloud.contact_center_insights_v1.types.ExportInsightsDataRequest.BigQueryDestination):
             Specified if sink is a BigQuery table.
+
             This field is a member of `oneof`_ ``destination``.
         parent (str):
             Required. The parent resource to export data
@@ -442,8 +461,19 @@ class ExportInsightsDataRequest(proto.Message):
             A fully qualified KMS key name for BigQuery
             tables protected by CMEK. Format:
             projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}/cryptoKeyVersions/{version}
+        write_disposition (google.cloud.contact_center_insights_v1.types.ExportInsightsDataRequest.WriteDisposition):
+            Options for what to do if the destination
+            table already exists.
     """
 
+    class WriteDisposition(proto.Enum):
+        r"""Specifies the action that occurs if the destination table
+        already exists.
+        """
+        WRITE_DISPOSITION_UNSPECIFIED = 0
+        WRITE_TRUNCATE = 1
+        WRITE_APPEND = 2
+
     class BigQueryDestination(proto.Message):
         r"""A BigQuery Table Reference.
 
@@ -473,6 +503,7 @@ class ExportInsightsDataRequest(proto.Message):
     parent = proto.Field(proto.STRING, number=1,)
     filter = proto.Field(proto.STRING, number=3,)
     kms_key = proto.Field(proto.STRING, number=4,)
+    write_disposition = proto.Field(proto.ENUM, number=5, enum=WriteDisposition,)
 
 
 class ExportInsightsDataMetadata(proto.Message):
@@ -866,6 +897,25 @@ class DeletePhraseMatcherRequest(proto.Message):
     name = proto.Field(proto.STRING, number=1,)
 
 
+class UpdatePhraseMatcherRequest(proto.Message):
+    r"""The request to update a phrase matcher.
+
+    Attributes:
+        phrase_matcher (google.cloud.contact_center_insights_v1.types.PhraseMatcher):
+            Required. The new values for the phrase
+            matcher.
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
+            The list of fields to be updated.
+    """
+
+    phrase_matcher = proto.Field(
+        proto.MESSAGE, number=1, message=resources.PhraseMatcher,
+    )
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
+
+
 class GetSettingsRequest(proto.Message):
     r"""The request to get project-level settings.
 
@@ -894,4 +944,103 @@ class UpdateSettingsRequest(proto.Message):
     )
 
 
+class CreateViewRequest(proto.Message):
+    r"""The request to create a view.
+
+    Attributes:
+        parent (str):
+            Required. The parent resource of the view. Required. The
+            location to create a view for. Format:
+            ``projects/<Project ID>/locations/<Location ID>`` or
+            ``projects/<Project Number>/locations/<Location ID>``
+        view (google.cloud.contact_center_insights_v1.types.View):
+            Required. The view resource to create.
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+    view = proto.Field(proto.MESSAGE, number=2, message=resources.View,)
+
+
+class GetViewRequest(proto.Message):
+    r"""The request to get a view.
+
+    Attributes:
+        name (str):
+            Required. The name of the view to get.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
+class ListViewsRequest(proto.Message):
+    r"""The request to list views.
+
+    Attributes:
+        parent (str):
+            Required. The parent resource of the views.
+        page_size (int):
+            The maximum number of views to return in the response. If
+            this value is zero, the service will select a default size.
+            A call may return fewer objects than requested. A non-empty
+            ``next_page_token`` in the response indicates that more data
+            is available.
+        page_token (str):
+            The value returned by the last ``ListViewsResponse``;
+            indicates that this is a continuation of a prior
+            ``ListViews`` call and the system should return the next
+            page of data.
+    """
+
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+
+
+class ListViewsResponse(proto.Message):
+    r"""The response of listing views.
+
+    Attributes:
+        views (Sequence[google.cloud.contact_center_insights_v1.types.View]):
+            The views that match the request.
+        next_page_token (str):
+            A token, which can be sent as ``page_token`` to retrieve the
+            next page. If this field is omitted, there are no subsequent
+            pages.
+    """
+
+    @property
+    def raw_page(self):
+        return self
+
+    views = proto.RepeatedField(proto.MESSAGE, number=1, message=resources.View,)
+    next_page_token = proto.Field(proto.STRING, number=2,)
+
+
+class UpdateViewRequest(proto.Message):
+    r"""The request to update a view.
+
+    Attributes:
+        view (google.cloud.contact_center_insights_v1.types.View):
+            Required. The new view.
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
+            The list of fields to be updated.
+    """
+
+    view = proto.Field(proto.MESSAGE, number=1, message=resources.View,)
+    update_mask = proto.Field(
+        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    )
+
+
+class DeleteViewRequest(proto.Message):
+    r"""The request to delete a view.
+
+    Attributes:
+        name (str):
+            Required. The name of the view to delete.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
