@@ -60,6 +60,7 @@ __protobuf__ = proto.module(
         "SmartComposeSuggestionData",
         "DialogflowInteractionData",
         "ConversationParticipant",
+        "View",
     },
 )
 
@@ -77,16 +78,19 @@ class Conversation(proto.Message):
     Attributes:
         call_metadata (google.cloud.contact_center_insights_v1.types.Conversation.CallMetadata):
             Call-specific metadata.
+
             This field is a member of `oneof`_ ``metadata``.
         expire_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which this conversation should
             expire. After this time, the conversation data
             and any associated analyses will be deleted.
+
             This field is a member of `oneof`_ ``expiration``.
         ttl (google.protobuf.duration_pb2.Duration):
             Input only. The TTL for this resource. If
             specified, then this TTL will be used to
             calculate the expire time.
+
             This field is a member of `oneof`_ ``expiration``.
         name (str):
             Immutable. The resource name of the
@@ -137,6 +141,9 @@ class Conversation(proto.Message):
             intents in the call. The key corresponds to a
             Dialogflow intent, format:
             projects/{project}/agent/{agent}/intents/{intent}
+        obfuscated_user_id (str):
+            Obfuscated user ID which the customer sent to
+            us.
     """
 
     class Medium(proto.Enum):
@@ -303,6 +310,7 @@ class Conversation(proto.Message):
     dialogflow_intents = proto.MapField(
         proto.STRING, proto.MESSAGE, number=18, message="DialogflowIntent",
     )
+    obfuscated_user_id = proto.Field(proto.STRING, number=21,)
 
 
 class Analysis(proto.Message):
@@ -348,10 +356,12 @@ class ConversationDataSource(proto.Message):
         gcs_source (google.cloud.contact_center_insights_v1.types.GcsSource):
             A Cloud Storage location specification for
             the audio and transcript.
+
             This field is a member of `oneof`_ ``source``.
         dialogflow_source (google.cloud.contact_center_insights_v1.types.DialogflowSource):
             The source when the conversation comes from
             Dialogflow.
+
             This field is a member of `oneof`_ ``source``.
     """
 
@@ -406,6 +416,7 @@ class AnalysisResult(proto.Message):
         call_analysis_metadata (google.cloud.contact_center_insights_v1.types.AnalysisResult.CallAnalysisMetadata):
             Call-specific metadata created by the
             analysis.
+
             This field is a member of `oneof`_ ``metadata``.
         end_time (google.protobuf.timestamp_pb2.Timestamp):
             The time at which the analysis ended.
@@ -462,7 +473,8 @@ class IssueModelResult(proto.Message):
 
     Attributes:
         issue_model (str):
-            Issue model that generates the result.
+            Issue model that generates the result. Format:
+            projects/{project}/locations/{location}/issueModels/{issue_model}
         issues (Sequence[google.cloud.contact_center_insights_v1.types.IssueAssignment]):
             All the matched issues.
     """
@@ -519,24 +531,31 @@ class CallAnnotation(proto.Message):
     Attributes:
         interruption_data (google.cloud.contact_center_insights_v1.types.InterruptionData):
             Data specifying an interruption.
+
             This field is a member of `oneof`_ ``data``.
         sentiment_data (google.cloud.contact_center_insights_v1.types.SentimentData):
             Data specifying sentiment.
+
             This field is a member of `oneof`_ ``data``.
         silence_data (google.cloud.contact_center_insights_v1.types.SilenceData):
             Data specifying silence.
+
             This field is a member of `oneof`_ ``data``.
         hold_data (google.cloud.contact_center_insights_v1.types.HoldData):
             Data specifying a hold.
+
             This field is a member of `oneof`_ ``data``.
         entity_mention_data (google.cloud.contact_center_insights_v1.types.EntityMentionData):
             Data specifying an entity mention.
+
             This field is a member of `oneof`_ ``data``.
         intent_match_data (google.cloud.contact_center_insights_v1.types.IntentMatchData):
             Data specifying an intent match.
+
             This field is a member of `oneof`_ ``data``.
         phrase_match_data (google.cloud.contact_center_insights_v1.types.PhraseMatchData):
             Data specifying a phrase match.
+
             This field is a member of `oneof`_ ``data``.
         channel_tag (int):
             The channel of the audio where the annotation
@@ -590,6 +609,7 @@ class AnnotationBoundary(proto.Message):
             The word index of this boundary with respect
             to the first word in the transcript piece. This
             index starts at zero.
+
             This field is a member of `oneof`_ ``detailed_boundary``.
         transcript_index (int):
             The index in the sequence of transcribed
@@ -892,10 +912,13 @@ class IssueModelLabelStats(proto.Message):
             labeled_conversations_count (int):
                 Number of conversations attached to the issue
                 at this point in time.
+            display_name (str):
+                Display name of the issue.
         """
 
         issue = proto.Field(proto.STRING, number=1,)
         labeled_conversations_count = proto.Field(proto.INT64, number=2,)
+        display_name = proto.Field(proto.STRING, number=3,)
 
     analyzed_conversations_count = proto.Field(proto.INT64, number=1,)
     unclassified_conversations_count = proto.Field(proto.INT64, number=2,)
@@ -1034,6 +1057,7 @@ class PhraseMatchRuleConfig(proto.Message):
     Attributes:
         exact_match_config (google.cloud.contact_center_insights_v1.types.ExactMatchConfig):
             The configuration for the exact match rule.
+
             This field is a member of `oneof`_ ``config``.
     """
 
@@ -1142,18 +1166,23 @@ class RuntimeAnnotation(proto.Message):
     Attributes:
         article_suggestion (google.cloud.contact_center_insights_v1.types.ArticleSuggestionData):
             Agent Assist Article Suggestion data.
+
             This field is a member of `oneof`_ ``data``.
         faq_answer (google.cloud.contact_center_insights_v1.types.FaqAnswerData):
             Agent Assist FAQ answer data.
+
             This field is a member of `oneof`_ ``data``.
         smart_reply (google.cloud.contact_center_insights_v1.types.SmartReplyData):
             Agent Assist Smart Reply data.
+
             This field is a member of `oneof`_ ``data``.
         smart_compose_suggestion (google.cloud.contact_center_insights_v1.types.SmartComposeSuggestionData):
             Agent Assist Smart Compose suggestion data.
+
             This field is a member of `oneof`_ ``data``.
         dialogflow_interaction (google.cloud.contact_center_insights_v1.types.DialogflowInteractionData):
             Dialogflow interaction data.
+
             This field is a member of `oneof`_ ``data``.
         annotation_id (str):
             The unique identifier of the annotation. Format:
@@ -1373,10 +1402,12 @@ class ConversationParticipant(proto.Message):
             The name of the participant provided by
             Dialogflow. Format:
             projects/{project}/locations/{location}/conversations/{conversation}/participants/{participant}
+
             This field is a member of `oneof`_ ``participant``.
         user_id (str):
             A user-specified ID representing the
             participant.
+
             This field is a member of `oneof`_ ``participant``.
         dialogflow_participant (str):
             Deprecated. Use ``dialogflow_participant_name`` instead. The
@@ -1405,4 +1436,31 @@ class ConversationParticipant(proto.Message):
     role = proto.Field(proto.ENUM, number=2, enum=Role,)
 
 
+class View(proto.Message):
+    r"""The View resource.
+
+    Attributes:
+        name (str):
+            Immutable. The resource name of the view.
+            Format:
+            projects/{project}/locations/{location}/views/{view}
+        display_name (str):
+            The human-readable display name of the view.
+        create_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The time at which this view was
+            created.
+        update_time (google.protobuf.timestamp_pb2.Timestamp):
+            Output only. The most recent time at which
+            the view was updated.
+        value (str):
+            String with specific view properties.
+    """
+
+    name = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
+    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    value = proto.Field(proto.STRING, number=5,)
+
+
 __all__ = tuple(sorted(__protobuf__.manifest))
